.. _ydoc directive_3 directive_3_1 directive_3_1_1 directive_3_1_1_1:

``directive_3_1_1_1``
=====================

This is a description of Directive 3.1.1.1

Single-valued parameters:

  * ``d3111v1``: Value 1 of D 3.1.1.1 (default: ABC)

  * ``d3111v2``: Value 2 of D 3.1.1.1



----

This page was automatically generated by **ycleptic** v1.8.0 on 2025-08-04.